@@ -16,12 +16,12 @@ app = Flask(__name__)
 
 
 
-os.system(f"echo {time.ctime()} >> ./log/test.log")
+# os.system(f"echo {time.ctime()} >> ./log/test.log")
 
 
 @app.route('/')
 def index():
     return 'hello world!'
 
-# if __name__ == '__main__':
-#     # app.run()
+if __name__ == '__main__':
+    app.run('0.0.0.0')
