@@ -13,7 +13,6 @@ from paddlenlp.taskflow.taskflow import Taskflow as _Taskflow, TASKS
 
 # ME
 from meutils.pipe import *
-from meutils.str_utils import dictstr2dict
 from appzoo import App
 
 Taskflow = singleton(_Taskflow)
@@ -35,7 +34,8 @@ app = App()
 app_ = app.app
 
 app.add_route_plus('/', get_tasks)
-app.add_route_plus('/inference', paddlenlp_inference, 'POST')
+app.add_route_plus('/inference', paddlenlp_inference, 'POST', plus='NB', i=0)
+app.add_route_plus('/raw', lambda x: x)
 
 if __name__ == '__main__':
     app.run(app.app_from(__file__), port=9955, debug=True)
